pitchtools.Segment
==================

.. abjad-lineage:: abjad.tools.pitchtools.Segment.Segment

.. autoclass:: abjad.tools.pitchtools.Segment.Segment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Segment.Segment.count
      ~abjad.tools.pitchtools.Segment.Segment.from_selection
      ~abjad.tools.pitchtools.Segment.Segment.has_duplicates
      ~abjad.tools.pitchtools.Segment.Segment.index
      ~abjad.tools.pitchtools.Segment.Segment.item_class
      ~abjad.tools.pitchtools.Segment.Segment.items
      ~abjad.tools.pitchtools.Segment.Segment.__add__
      ~abjad.tools.pitchtools.Segment.Segment.__contains__
      ~abjad.tools.pitchtools.Segment.Segment.__eq__
      ~abjad.tools.pitchtools.Segment.Segment.__format__
      ~abjad.tools.pitchtools.Segment.Segment.__getitem__
      ~abjad.tools.pitchtools.Segment.Segment.__getslice__
      ~abjad.tools.pitchtools.Segment.Segment.__hash__
      ~abjad.tools.pitchtools.Segment.Segment.__iter__
      ~abjad.tools.pitchtools.Segment.Segment.__len__
      ~abjad.tools.pitchtools.Segment.Segment.__mul__
      ~abjad.tools.pitchtools.Segment.Segment.__ne__
      ~abjad.tools.pitchtools.Segment.Segment.__radd__
      ~abjad.tools.pitchtools.Segment.Segment.__repr__
      ~abjad.tools.pitchtools.Segment.Segment.__rmul__
      ~abjad.tools.pitchtools.Segment.Segment.__str__

Bases
-----

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Segment.Segment.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Segment.Segment.item_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Segment.Segment.items
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.Segment.Segment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.from_selection
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.index
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__radd__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Segment.Segment.__str__
   :noindex:
